==> digikam-7.2.0-rc.tar.xz: digikam-7.2.0-rc/core/dplugins/generic/tools/htmlgallery/parameters/abstractthemeparameter.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2006-04-04
 * Description : a tool to generate HTML image galleries
 *
 * Copyright (C) 2006-2010 by Aurelien Gateau <aurelien dot gateau at free dot fr>
 * Copyright (C) 2012-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_ABSTRACT_THEME_PARAMETER_H
#define DIGIKAM_ABSTRACT_THEME_PARAMETER_H

class QByteArray;
class QString;
class QWidget;

class KConfigGroup;

namespace DigikamGenericHtmlGalleryPlugin
{

/**
 * Represents a theme parameter. For each type of parameter, one should inherit
 * from this class and add the necessary code in the Theme class to load the
 * new type.
 */
class AbstractThemeParameter
{
public:

    explicit AbstractThemeParameter();
    virtual ~AbstractThemeParameter();

    /**
     * Reads theme parameters from configGroup. Initializes the internalName,
     * name and defaultValue fields.
     */
    virtual void init(const QByteArray& internalName, const KConfigGroup* configGroup);

    QByteArray internalName() const;
    QString name()            const;
    QString defaultValue()    const;

    /**
     * This method should return a QWidget representing the parameter,
     * initialized with value.
     */
    virtual QWidget* createWidget(QWidget* parent, const QString& value) const = 0;

    /**
     * The opposite of createWidget: given a widget previously created with
     * createWidget, this method returns the current widget value.
     */
    virtual QString valueFromWidget(QWidget*) const = 0;

private:

    // Hidden copy constructor and assignment operator.
    AbstractThemeParameter(const AbstractThemeParameter&);
    AbstractThemeParameter& operator=(const AbstractThemeParameter&);

    class Private;
    Private* const d;
};

} // namespace DigikamGenericHtmlGalleryPlugin

#endif // DIGIKAM_ABSTRACT_THEME_PARAMETER_H

==> digikam_7.5.0.orig.tar.xz: digikam-7.5.0/core/dplugins/generic/tools/htmlgallery/parameters/abstractthemeparameter.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2006-04-04
 * Description : a tool to generate HTML image galleries
 *
 * Copyright (C) 2006-2010 by Aurelien Gateau <aurelien dot gateau at free dot fr>
 * Copyright (C) 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_ABSTRACT_THEME_PARAMETER_H
#define DIGIKAM_ABSTRACT_THEME_PARAMETER_H

class QByteArray;
class QString;
class QWidget;

class KConfigGroup;

namespace DigikamGenericHtmlGalleryPlugin
{

/**
 * Represents a theme parameter. For each type of parameter, one should inherit
 * from this class and add the necessary code in the Theme class to load the
 * new type.
 */
class AbstractThemeParameter
{
public:

    explicit AbstractThemeParameter();
    virtual ~AbstractThemeParameter();

    /**
     * Reads theme parameters from configGroup. Initializes the internalName,
     * name and defaultValue fields.
     */
    virtual void init(const QByteArray& internalName, const KConfigGroup* configGroup);

    QByteArray internalName() const;
    QString name()            const;
    QString defaultValue()    const;

    /**
     * This method should return a QWidget representing the parameter,
     * initialized with value.
     */
    virtual QWidget* createWidget(QWidget* parent, const QString& value) const = 0;

    /**
     * The opposite of createWidget: given a widget previously created with
     * createWidget, this method returns the current widget value.
     */
    virtual QString valueFromWidget(QWidget*) const = 0;

private:

    // Disable
    AbstractThemeParameter(const AbstractThemeParameter&)            = delete;
    AbstractThemeParameter& operator=(const AbstractThemeParameter&) = delete;

private:

    class Private;
    Private* const d;
};

} // namespace DigikamGenericHtmlGalleryPlugin

#endif // DIGIKAM_ABSTRACT_THEME_PARAMETER_H
